function [data] = neuromag_load_extra_data(fiffile, extra_info, session_no)
% load data from fiffile.
% [USAGE]
%    [data] = neuromag_load_meg_data(<fiffile>, <session_no>);
% [IN]
%          fiffile : fiffile(Raw file or Evoked file)
% session_no : data index in fiffile.
%                   % = -1 : continuous raw data
%                   % >= 0 : Evoked data index
% [OUT]
%    data : The data of one channel in each row, a single time sample in
%           each column. Units: SI units. fT/m for gradiometers, fT for
%           magnetometers, V for electric channels.
%
% Copyright (C) 2011, ATR All Rights Reserved.
% License : New BSD License(see VBMEG_LICENSE.txt)


%
% --- Previous check
%
if ~exist('fiffile', 'var')
    error('fiffile is a required parameter.');
end
if ~exist('session_no', 'var')
    error('session_no is a required parameter.');
end
if exist(fiffile, 'file') ~= 2
    error('fiffile:%s is not found.', fiffile);
end

%
% --- Main Procedure
%
F  = neuromag_load_fiff(fiffile);

ex_ix = extra_info.Channel_id;

if session_no < 0
    % load Continuous data
    data=diag(F.CalXRnge(ex_ix))*double(F.raw_data(ex_ix, :));
    Nsample=F.rawdata.Nsample;
else
    Nsets   = F.loadfif.Nsets;
    Comment = F.loadfif.Comment;
    % load Evoked data
    if session_no >= Nsets
        error('invalid fiffile data index were specified.');
    end
    
    data = F.loadfif.B{session_no+1};
	% Select extra channel
	data = data(ex_ix, :);
end
