function [bexp, sf, Nsample] = neuromag_load_rawdata(fiffile)
% load neuromag rawdata-fiffile.(continuous data)
% [USAGE]
%    [data] = neuromag_load_rawdata(<fiffile>);
% [IN]
%    fiffile : neuromag rawdata fiffile.
% [OUT]
%       bexp : The data of one channel in each row, a single time
%              sample in each column. [Nch x Nsample]
%              (Units: SI units. fT/m forgradiometers, 
%              fT for magnetometers, V for electric channels.)
%         sf : Sampling Frequency(Units:Hz) [double]
%    Nsample : The number of samples.  [double]
%
%
% Copyright (C) 2011, ATR All Rights Reserved.
% License : New BSD License(see VBMEG_LICENSE.txt)

%
% --- Previous check
%
if ~exist('fiffile', 'var')
    error('fiffile is a required parameter.');
end
if exist(fiffile, 'file') ~= 2
    error('fiffile:%s is not found.', fiffile);
end

%
%
% --- Read Data
%

F = neuromag_load_fiff(fiffile);

% get info
sf      = F.rawdata.SampleFreq;
Nsample = F.rawdata.Nsample;

% read data
ch = find(F.channames.grad_kind==1); % meg data channel

bexp = diag(F.CalXRnge(ch)) * double(F.raw_data(ch, :));
fprintf('\nfinished. [%d/%d]\n',Nsample, Nsample);
